@@ -1,6 +1,7 @@
 from distutils.sysconfig import get_python_lib
 import threading
 import os
+import socket
 
 from bugsnag.utils import fully_qualified_class_name
 
@@ -46,6 +47,10 @@ class Configuration(_BaseConfiguration):
         self.params_filters = ["password", "password_confirmation"]
         self.ignore_classes = []
         self.endpoint = "notify.bugsnag.com"
+        if not os.getenv("DYNO"):
+            self.hostname = socket.gethostname()
+        else:
+            self.hostname = None
 
     def should_notify(self):
         return self.notify_release_stages is None or \
